@@ -1,13 +1,13 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2018-2023, by Samuel Williams.
-# Copyright, 2019, by destructobeam.
+# Copyright, 2018-2024, by Samuel Williams.
+# Copyright, 2019, by Simon Crocker.
 
-require_relative 'connection'
-require_relative 'response'
+require_relative "connection"
+require_relative "response"
 
-require 'protocol/http/middleware'
+require "protocol/http/middleware"
 
 module Async
 	module WebSocket
